package edu.fiu.jtlex.algorithms;

import org.jacop.core.IntVar;

import edu.fiu.jtlex.timeml.graph.ITimeMLGraphTCSP;

import java.util.List;

/**
 * Abstraction for a TCSP solver
 *
 * @since jTLEX 1.0
 */
public interface IGraphTCSPSolver {

    // TODO: Avoid primitive obsession by replacing List<IntVar> with ITCSPSolution

    /**
     * Solves the given TCSP using minimum selection.
     *
     * @param problem The problem to solve
     * @return The solution to the problem
     * @throws NullPointerException If the problem is null
     * @since jTLEX 1.0
     */
    List<IntVar> solve(ITimeMLGraphTCSP problem);

    /**
     * Solves the given TCSP using random selection.
     *
     * @param problem The problem to solve
     * @return The solution to the problem
     * @throws NullPointerException If the problem is null
     * @since jTLEX 1.0
     */
    List<IntVar> solveRandom(ITimeMLGraphTCSP problem);

    /**
     * Converts a solution into its string representation
     *
     * @param solution The solution to convert
     * @return A string representation of the solution
     * @throws NullPointerException If the solution is null
     * @since jTLEX 1.0
     */
    List<String> convertSolutionToString(List<IntVar> solution);
}
