package edu.fiu.jtlex.algorithms;

import java.util.Set;

import edu.fiu.jtlex.timeml.data.ITimeMLLink;
import edu.fiu.jtlex.timeml.graph.ITimeMLGraph;
import edu.fiu.jtlex.timeml.graph.ITimeMLNode;

/**
 * An abstraction for inconsistency detection.
 * @since jTLEX 1.0
 */
public interface IInconsistencyDetector {

    /**
     * A method to verify the consistency of a graph.
     *
     * @param timeMLGraph A timeML graph object with a non empty set of nodes.
     * @return true if the graph is consistent, false if the graph is inconsistent.
     * @throws NullPointerException if null is passed in
     * @throws IllegalStateException If the timeMLGraph contains any S-Link
     * @since jTLEX 1.0
     */
    boolean isConsistent(ITimeMLGraph timeMLGraph);
    
    /**
     * Given a set of links, identifies which are inconsistent self references,
     * and produces a subgraph for each instance.
     *
     * @param links A set of links.
     * @param nodes A set of nodes.
     * @return A set of IGraphs, each containing inconsistent self looping nodes.
     * @throws NullPointerException If links is null.
     * @since jTLEX 1.0
     */
    public Set<ITimeMLGraph> generateSelfLoopingSubGraphs(Set<ITimeMLLink> links, Set<ITimeMLNode> nodes);

    /**
     * Generates a set of subgraphs that contain all the links and nodes involved
     * in the inconsistencies.
     *
     * @param timeMLGraph TimeML graph to evaluate.
     * @return A set containing the inconsistent subgraphs.
     * @throws NullPointerException if null is passed in
     * @since jTLEX 1.0
     */
    Set<ITimeMLGraph> generateInconsistentSubgraphs(ITimeMLGraph timeMLGraph);

}
