package edu.fiu.jtlex.timeml.data;

import java.util.Set;

/**
 * Text objects are a placeholder for pre-analyzed, parsed data.
 * These have objects that contain {@code Time Expressions}, {@code Links}, 
 * {@code Instances}, {@code Related Instances}, and the Raw Text Data (with and without TimeML Tags). 
 * @since jTLEX 1.0
 */	
public interface ITimeMLText {
	
	/**
	 * Returns the article text without TimeML tags. 
	 * @return the article text without TimeML tags.
	 * @since jTLEX 1.0
	 */
	public String getText();
	
	/**
	 * Returns the article text with TimeML tags. 
	 * This is the original text file that was input.
	 * @return the article text with TimeML tags.
	 * @since jTLEX 1.0
	 */
	public String getRawText();
	
	/**
	 * Returns a set view of all the TIMEXes. 
	 * @return a set view of all the TIMEXes.
	 * @since jTLEX 1.0
	 */
	public Set<ITimeMLTimex> getTimexes();
	
	/**
	 * Returns a set view of all the links. 
	 * @return a set view of all the links.
	 * @since jTLEX 1.0
	 */
	public Set<ITimeMLLink> getLinks();
	
	/**
	 * Returns a set view of all the instances. 
	 * @return a set view of all the instances.
	 * @since jTLEX 1.0
	 */
	public Set<ITimeMLInstance> getInstances();
	
    /**
	 * Returns a set view of all the events. 
	 * @return a set view of all the events.
     * @since jTLEX 1.0
     */
    public Set<ITimeMLEvent> getEvents();
	
	/**
	 * Returns the Instances related to the event passed.
	 * @param event the event in question.
	 * @return the Instances related to the event passed.
	 * @since jTLEX 1.0
	 */
	public Set<ITimeMLInstance> getRelatedInstances(ITimeMLEvent event);
	
    /**
	 * Generates a hash code for the text.
	 *
	 * @return The hash code.
	 * @since jTLEX 1.0
	 */
    @Override
    public int hashCode();
	
	/**
	 * Checks if this text equals an object.
	 *
	 * @param o	The object to compare against.
	 * @return True if both texts are equal, i.e. same rawText, or else false.
     * @throws NullPointerException If the object to compare against is false.
	 * @since jTLEX 1.0
	 */
    @Override
    public boolean equals(Object o);
	
	
}
