package edu.fiu.jtlex.timeml.graph;

import edu.fiu.jtlex.timeml.data.ITimeMLEvent;
import edu.fiu.jtlex.timeml.data.ITimeMLTimex;

/**
 * Super interface for Instances and Timexs.
 * @since jTLEX 1.0
 */	
public interface ITimeMLNode {
	
	/**
	 * Wrapper interface for {@link ITimeMLEvent.EventClass} and {@link ITimeMLTimex.TimexType}.
	 * Essentially allows for the creation of Nodes that can be either Events or Timexes.
	 * When creating a node, a user needs to be able to grab the enum (EventClass/TimexType)
	 * that represents its type. Since those two are represented as different types of enums, this 
	 * interface acts as a wrapper so it can grab either one depending on whichever one the node is.
	 * @see ITimeMLNode
	 * @since jTLEX 1.0
	 */
	public interface IType {

	}
	/**
	 * Returns the integer part of the node ID. 
	 * Each event has to be identified by a unique ID number. 
	 * 
	 * @return Integer part of the node ID. May not be 0 or negative.
	 * @since jTLEX 1.0
	 */
	public int getId();

	/**
	 * Return the integer that corresponds with the type. 
	 * Each event can be categorized under three different types. 
	 * 
	 * @return Enum that corresponds with the type of node.
	 * @since jTLEX 1.0
	 */
	public IType getType();

	/**
	 * Returns the full string representation of the node ID.
	 * Each event has to be identified by a unique ID number and String. 
	 * 
	 * @return Full string representation of the node ID. May not return <code>null</code>.
	 * @since jTLEX 1.0
	 */
	public String getIdStr();
	
	
	/**
	 * Compares the given object to another of the same type.
	 * @return True if equals, false otherwise.
	 * @throws NullPointerException if object to compare against is false
	 * @since jTLEX 1.0
	 */
	@Override
	public boolean equals(Object o);
	
	/**
	 * Returns the JSON (RFC 8259) representation of the Node.
	 * @return the JSON (RFC 8259) representation of the Node.
	 * @since jTLEX 1.0
	 */
	public String toJson();

	/**
	 * Returns a field-by-field of the Node.
	 * @return  a field-by-field copy of the Node.
	 * @since jTLEX 1.0
	 */
	public ITimeMLNode clone();
}
